unit BitUnit;

interface



function IsBitSet(const i, Nth: integer): boolean;
function BitToOn(const i, Nth: integer): integer;
function BitToOff(const i, Nth: integer): integer;
function BitSwitch(const i, Nth: integer): integer;
function ReverseAllBits(const i: integer): integer;

implementation




{------------------------------IsBitSet------------------------------------------
  returns True if a bit is ON (1)
  Nth can have any bit order value in [0..31]
----------------------------------------------------------------------------------}
function IsBitSet(const i, Nth: integer): boolean;
begin
  Result:= (i and (1 shl Nth)) <> 0;
end; { IsBitSet }
{----------------------------BitToOn-----------------------------------------------}
function BitToOn(const i, Nth: integer): integer;
begin
  if not IsBitSet(i, Nth)
  then Result := i or (1 shl Nth)
  else Result:=i;
end;  { BitToOn }
{-------------------------BitToOff------------------------------------------------}
function BitToOff(const i, Nth: integer): integer;
begin
  if IsBitSet(i, Nth)
  then Result := i and ((1 shl Nth) xor $FFFFFFFF)
  else Result:=i;
end;  { BitToOff }
{---------------------------BitSwitch---------------------------------------------
 reverse the state of a bit
----------------------------------------------------------------------------------}
function BitSwitch(const i, Nth: integer): integer;
begin
  Result := i xor (1 shl Nth);
end;  { BitSwitch }


{-----------------------ReverseAllBits--------------------------------------------
 has the same effect as the ~ (one's complement) operator in C
----------------------------------------------------------------------------------}
function ReverseAllBits(const i: integer): integer;
var
 N:integer;
begin
  Result:= i;
  for N:=0 to 31 do  Result:= Result xor (1 shl N);
end;  { ReverseAllBits }





end.
